==> print-js-bugfix-1.0.0.tgz: package/src/js/pdf.js <==
import Print from './print'
import { cleanUp } from './functions'

export default {
  print: (params, printFrame) => {
    console.log(params, printFrame,'params, printFrame')
    if (!Int8Array.__proto__.from) {
      (function () {
          Int8Array.__proto__.from = function (obj, func, thisObj) {
  
              var typedArrayClass = Int8Array.__proto__;
              if(typeof this !== 'function') {
                  throw new TypeError('# is not a constructor');
              }
              if (this.__proto__ !== typedArrayClass) {
                  throw new TypeError('this is not a typed array.');
              }
  
              func = func || function (elem) {
                      return elem;
                  };
  
              if (typeof func !== 'function') {
                  throw new TypeError('specified argument is not a function');
              }
  
              obj = Object(obj);
              if (!obj['length']) {
                  return new this(0);
              }
              var copy_data = [];
              for(var i = 0; i < obj.length; i++) {
                  copy_data.push(obj[i]);
              }
  
              copy_data = copy_data.map(func, thisObj);
  
              var typed_array = new this(copy_data.length);
              for(var i = 0; i < typed_array.length; i++) {
                  typed_array[i] = copy_data[i];
              }
              return typed_array;
          }
      })();
   }
    // Check if we have base64 data
    if (params.base64) {
      const bytesArray = Uint8Array.from(atob(params.printable), c => c.charCodeAt(0))
      createBlobAndPrint(params, printFrame, bytesArray)
      return
    }

    // Format pdf url
    params.printable = /^(blob|http|\/\/)/i.test(params.printable)
      ? params.printable
      : window.location.origin + (params.printable.charAt(0) !== '/' ? '/' + params.printable : params.printable)

    // Get the file through a http request (Preload)
    const req = new window.XMLHttpRequest()
    req.responseType = 'arraybuffer'

    req.addEventListener('error', () => {
      cleanUp(params)
      params.onError(req.statusText, req)

      // Since we don't have a pdf document available, we will stop the print job
    })

    req.addEventListener('load', () => {
      // Check for errors
      if ([200, 201].indexOf(req.status) === -1) {
        cleanUp(params)
        params.onError(req.statusText, req)

        // Since we don't have a pdf document available, we will stop the print job
        return
      }

      // Print requested document
      createBlobAndPrint(params, printFrame, req.response)
    })

    req.open('GET', params.printable, true)
    req.send()
  }
}

function createBlobAndPrint (params, printFrame, data) {
  // Pass response or base64 data to a blob and create a local object url
  let localPdf = new window.Blob([data], { type: 'application/pdf' })
  localPdf = window.URL.createObjectURL(localPdf)

  // Set iframe src with pdf document url
  printFrame.setAttribute('src', localPdf)

  Print.send(params, printFrame)
}

==> print-js-bugfix-1.0.2.tgz: package/src/js/pdf.js <==
import Print from './print'
import { cleanUp } from './functions'

export default {
  print: (params, printFrame) => {
    console.log(params, printFrame,'params, printFrame')
    if (!Uint8Array.__proto__.from) {
      (function () {
        Uint8Array.__proto__.from = function (obj, func, thisObj) {
  
              var typedArrayClass = Uint8Array.__proto__;
              if(typeof this !== 'function') {
                  throw new TypeError('# is not a constructor');
              }
              if (this.__proto__ !== typedArrayClass) {
                  throw new TypeError('this is not a typed array.');
              }
  
              func = func || function (elem) {
                      return elem;
                  };
  
              if (typeof func !== 'function') {
                  throw new TypeError('specified argument is not a function');
              }
  
              obj = Object(obj);
              if (!obj['length']) {
                  return new this(0);
              }
              var copy_data = [];
              for(var i = 0; i < obj.length; i++) {
                  copy_data.push(obj[i]);
              }
  
              copy_data = copy_data.map(func, thisObj);
  
              var typed_array = new this(copy_data.length);
              for(var i = 0; i < typed_array.length; i++) {
                  typed_array[i] = copy_data[i];
              }
              return typed_array;
          }
      })();
   }
    // Check if we have base64 data
    if (params.base64) {
      const bytesArray = Array.from(atob(params.printable), c => c.charCodeAt(0))
      createBlobAndPrint(params, printFrame, bytesArray)
      return
    }

    // Format pdf url
    params.printable = /^(blob|http|\/\/)/i.test(params.printable)
      ? params.printable
      : window.location.origin + (params.printable.charAt(0) !== '/' ? '/' + params.printable : params.printable)

    // Get the file through a http request (Preload)
    const req = new window.XMLHttpRequest()
    req.responseType = 'arraybuffer'

    req.addEventListener('error', () => {
      cleanUp(params)
      params.onError(req.statusText, req)

      // Since we don't have a pdf document available, we will stop the print job
    })

    req.addEventListener('load', () => {
      // Check for errors
      if ([200, 201].indexOf(req.status) === -1) {
        cleanUp(params)
        params.onError(req.statusText, req)

        // Since we don't have a pdf document available, we will stop the print job
        return
      }

      // Print requested document
      createBlobAndPrint(params, printFrame, req.response)
    })

    req.open('GET', params.printable, true)
    req.send()
  }
}

function createBlobAndPrint (params, printFrame, data) {
  // Pass response or base64 data to a blob and create a local object url
  let localPdf = new window.Blob([data], { type: 'application/pdf' })
  localPdf = window.URL.createObjectURL(localPdf)

  // Set iframe src with pdf document url
  printFrame.setAttribute('src', localPdf)

  Print.send(params, printFrame)
}
